Class: Soaspec::Tester
- Inherits:
-
Object
- Object
- Soaspec::Tester
- Defined in:
- lib/soaspec/tester.rb
Overview
Has basic methods common for methods defining RSpec tests in YAML
Direct Known Subclasses
Instance Attribute Summary collapse
-
#template_name ⇒ Object
Retrieve the name of the template file to be used in the API request.
Instance Method Summary collapse
-
#initialize(name, options) ⇒ Tester
constructor
Set instance variable name.
-
#to_s ⇒ String
Sets api handler variable globally.
Constructor Details
#initialize(name, options) ⇒ Tester
Set instance variable name
12 13 14 |
# File 'lib/soaspec/tester.rb', line 12 def initialize(name, ) @name = name end |
Instance Attribute Details
#template_name ⇒ Object
Retrieve the name of the template file to be used in the API request
7 8 9 |
# File 'lib/soaspec/tester.rb', line 7 def template_name @template_name end |
Instance Method Details
#to_s ⇒ String
Sets api handler variable globally. This is used in ‘Exchange’ class
18 19 20 21 |
# File 'lib/soaspec/tester.rb', line 18 def to_s Soaspec::Environment.api_handler = self @name end |