Module: Soaspec
- Defined in:
- lib/soaspec.rb,
lib/soaspec/version.rb,
lib/soaspec/exe_helpers.rb,
lib/soaspec/spec_logger.rb,
lib/soaspec/wsdl_generator.rb,
lib/soaspec/test_server/get_bank.rb,
lib/soaspec/test_server/invoices.rb,
lib/soaspec/test_server/puppy_service.rb,
lib/soaspec/test_server/test_attribute.rb,
lib/soaspec/exchange_handlers/rest_handler.rb,
lib/soaspec/exchange_handlers/rest_methods.rb,
lib/soaspec/exchange_handlers/soap_handler.rb,
lib/soaspec/exchange_handlers/exchange_handler.rb,
lib/soaspec/exchange_handlers/handler_accessors.rb
Overview
Gem for handling SOAP and REST api tests
Defined Under Namespace
Modules: ExeHelpers, HandlerAccessors, RestAccessors, RestMethods, SoapAccessors, TestServer, WsdlGenerator Classes: BasicSoapHandler, ExchangeHandler, RestHandler, SoapHandler, SpecLogger
Constant Summary collapse
- VERSION =
'0.0.79'.freeze
Class Method Summary collapse
-
.always_use_keys=(use_keys) ⇒ Object
Set whether to transform strings to keys in request automatically.
-
.always_use_keys? ⇒ Boolean
Whether to transform strings to keys in request automatically.
-
.api_handler ⇒ Object
Exchange Handler class currently being used.
-
.api_handler=(handler) ⇒ Object
Used so that exchange class knows what context it’s in.
-
.credentials_folder ⇒ Object
Credentials folder used to store secret data (not in source control) E.g passwords.
-
.credentials_folder=(folder) ⇒ Object
Folder used to store credentials Used in auth2_file command.
-
.strip_namespaces=(remove_namespaces) ⇒ Object
Whether to remove namespaces from response in Xpath assertion automatically For why this may not be a good thing in general see tenderlovemaking.com/2009/04/23/namespaces-in-xml.html This will be overridden if xpath has a ‘:’ in it.
-
.strip_namespaces? ⇒ Boolean
Whether to remove namespaces in xpath assertion automatically.
Class Method Details
.always_use_keys=(use_keys) ⇒ Object
Set whether to transform strings to keys in request automatically
61 62 63 |
# File 'lib/soaspec.rb', line 61 def always_use_keys=(use_keys) @always_use_keys = use_keys end |
.always_use_keys? ⇒ Boolean
Returns Whether to transform strings to keys in request automatically.
66 67 68 |
# File 'lib/soaspec.rb', line 66 def always_use_keys? @always_use_keys || true end |
.api_handler ⇒ Object
Exchange Handler class currently being used
55 56 57 |
# File 'lib/soaspec.rb', line 55 def api_handler @api_handler end |
.api_handler=(handler) ⇒ Object
Used so that exchange class knows what context it’s in
50 51 52 |
# File 'lib/soaspec.rb', line 50 def api_handler=(handler) @api_handler = handler end |
.credentials_folder ⇒ Object
Credentials folder used to store secret data (not in source control) E.g passwords
44 45 46 |
# File 'lib/soaspec.rb', line 44 def credentials_folder @credentials_folder end |
.credentials_folder=(folder) ⇒ Object
Folder used to store credentials Used in auth2_file command
39 40 41 |
# File 'lib/soaspec.rb', line 39 def credentials_folder=(folder) @credentials_folder = folder end |
.strip_namespaces=(remove_namespaces) ⇒ Object
Whether to remove namespaces from response in Xpath assertion automatically For why this may not be a good thing in general see tenderlovemaking.com/2009/04/23/namespaces-in-xml.html This will be overridden if xpath has a ‘:’ in it
74 75 76 |
# File 'lib/soaspec.rb', line 74 def strip_namespaces=(remove_namespaces) @strip_namespaces = remove_namespaces end |
.strip_namespaces? ⇒ Boolean
Whether to remove namespaces in xpath assertion automatically
79 80 81 |
# File 'lib/soaspec.rb', line 79 def strip_namespaces? @strip_namespaces || false end |