Module: Soaspec::Environment
- Defined in:
- lib/soaspec.rb
Overview
Represents Environment parameters used in Soaspec tests
Class Method Summary collapse
-
.always_use_keys=(use_keys) ⇒ Object
Whether to transform strings to keys automatically.
- .always_use_keys? ⇒ Boolean
- .api_handler ⇒ Object
-
.api_handler=(handler) ⇒ Object
Used so that exchange class knows what context it’s in.
-
.strip_namespaces=(remove_namespaces_from_response) ⇒ Object
Whether to remove namespaces from response in Xpath assertion automatically For why this may not be a good thing in general see tenderlovemaking.com/2009/04/23/namespaces-in-xml.html This will be overridden if xpath has a ‘:’ in it.
-
.strip_namespaces? ⇒ Boolean
Whether to remove namespaces in xpath assertion automatically.
Class Method Details
.always_use_keys=(use_keys) ⇒ Object
Whether to transform strings to keys automatically
42 43 44 |
# File 'lib/soaspec.rb', line 42 def self.always_use_keys=(use_keys) @always_use_keys = use_keys end |
.always_use_keys? ⇒ Boolean
46 47 48 |
# File 'lib/soaspec.rb', line 46 def self.always_use_keys? @always_use_keys || true end |
.api_handler ⇒ Object
37 38 39 |
# File 'lib/soaspec.rb', line 37 def self.api_handler @api_handler end |
.api_handler=(handler) ⇒ Object
Used so that exchange class knows what context it’s in
33 34 35 |
# File 'lib/soaspec.rb', line 33 def self.api_handler=(handler) @api_handler = handler end |
.strip_namespaces=(remove_namespaces_from_response) ⇒ Object
Whether to remove namespaces from response in Xpath assertion automatically For why this may not be a good thing in general see tenderlovemaking.com/2009/04/23/namespaces-in-xml.html This will be overridden if xpath has a ‘:’ in it
54 55 56 |
# File 'lib/soaspec.rb', line 54 def self.strip_namespaces=(remove_namespaces_from_response) @strip_namespaces = remove_namespaces_from_response end |
.strip_namespaces? ⇒ Boolean
Whether to remove namespaces in xpath assertion automatically
59 60 61 |
# File 'lib/soaspec.rb', line 59 def self.strip_namespaces? @strip_namespaces || false end |